commit cb0e1940ea181566c5af2550dedc842f84b9b145
Author: Leszek Koltunski <leszek@distorted.org>
Date:   Mon Jun 13 23:28:51 2016 +0100

    remove the remains of DistortedBitmaps from DistortedNode

diff --git a/src/main/java/org/distorted/library/DistortedNode.java b/src/main/java/org/distorted/library/DistortedNode.java
index 8d5a57b..4d39ba8 100644
--- a/src/main/java/org/distorted/library/DistortedNode.java
+++ b/src/main/java/org/distorted/library/DistortedNode.java
@@ -7,10 +7,10 @@ import android.opengl.GLES20;
 
 ///////////////////////////////////////////////////////////////////////////////////////////////////
 /**
- * Class which represents a Node in a Tree of DistortedBitmaps.
+ * Class which represents a Node in a Tree of DistortedObjects.
  *  
  * Having organized a set of DistortedBitmaps into a Tree, we can then render any Node to any Framebuffer.
  * That recursively renders the Bitmap held in the Node and all its children, along with whatever effects
  * each one of them has. 
  */
 public class DistortedNode 
@@ -359,15 +359,15 @@ public class DistortedNode
 /**
  * Adds a new child to the last position in the list of our Node's children.
  * 
  * @param bmp DistortedBitmap to initialize our child Node with.
  * @return the newly constructed child Node, or null if we couldn't allocate resources.
  */
-  public synchronized DistortedNode attach(DistortedBitmap bmp)
+  public synchronized DistortedNode attach(DistortedObject obj)
     {
     ArrayList<Long> prev = generateIDList(); 
       
     if( mChildren==null ) mChildren = new ArrayList<>(2);
-    DistortedNode node = new DistortedNode(bmp);
+    DistortedNode node = new DistortedNode(obj);
     node.mParent = this;
     mChildren.add(node);
     mNumChildren[0]++;
@@ -7,10 +7,10 @@ import android.opengl.GLES20;
  *  
- * Having organized a set of DistortedBitmaps into a Tree, we can then render any Node to any Framebuffer.
- * That recursively renders the Bitmap held in the Node and all its children, along with whatever effects
+ * Having organized a set of DistortedObjects into a Tree, we can then render any Node to any Framebuffer.
+ * That recursively renders the Object held in the Node and all its children, along with whatever effects
  * each one of them has. 
  */
@@ -359,15 +359,15 @@ public class DistortedNode
  * Adds a new child to the last position in the list of our Node's children.
  * 
- * @param bmp DistortedBitmap to initialize our child Node with.
+ * @param obj DistortedObject to initialize our child Node with.
  * @return the newly constructed child Node, or null if we couldn't allocate resources.
  */
